@@ -50,6 +50,15 @@ def make(path, docker):
     builder.make(path, docker_config=docker_config)
 
 
+@main.command()
+@click.argument("registry")
+def generate_makefile(registry):
+    """
+    Generates makefile
+    """
+    print(builder.compile_registry(registry))
+
+
 @main.command()
 @click.option("-o", "--output")
 @click.argument("ontology")
