@@ -151,6 +151,13 @@
 --     * Slot: datatype Description: 
 --     * Slot: language Description: 
 -- # Class: "owl_axiom_annotation" Description: ""
+--     * Slot: annotation_subject Description: 
+--     * Slot: annotation_predicate Description: 
+--     * Slot: annotation_object Description: 
+--     * Slot: annotation_value Description: 
+--     * Slot: annotation_language Description: 
+--     * Slot: annotation_datatype Description: 
+--     * Slot: id Description: An identifier for an element. Note blank node ids are not unique across databases
 --     * Slot: axiom_predicate Description: 
 --     * Slot: axiom_object Description: 
 --     * Slot: axiom_value Description: 
@@ -552,6 +559,13 @@ CREATE TABLE owl_axiom (
 	PRIMARY KEY (id)
 );
 CREATE TABLE owl_axiom_annotation (
+	annotation_subject TEXT, 
+	annotation_predicate TEXT, 
+	annotation_object TEXT, 
+	annotation_value TEXT, 
+	annotation_language TEXT, 
+	annotation_datatype TEXT, 
+	id TEXT, 
 	axiom_predicate TEXT, 
 	axiom_object TEXT, 
 	axiom_value TEXT, 
@@ -563,7 +577,8 @@ CREATE TABLE owl_axiom_annotation (
 	object TEXT, 
 	value TEXT, 
 	datatype TEXT, 
-	language TEXT
+	language TEXT, 
+	PRIMARY KEY (id)
 );
 CREATE TABLE anonymous_expression (
 	id TEXT, 
@@ -990,7 +1005,7 @@ DROP TABLE asymmetric_property_node;
 CREATE VIEW asymmetric_property_node AS SELECT DISTINCT subject AS id FROM rdf_type_statement WHERE object='owl:AsymmetricProperty';
 
 DROP TABLE annotation_property_node;
-CREATE VIEW annotation_property_node AS SELECT DISTINCT subject AS id FROM rdf_type_statement WHERE object='owl:AnnotatonProperty';
+CREATE VIEW annotation_property_node AS SELECT DISTINCT subject AS id FROM rdf_type_statement WHERE object='owl:AnnotationProperty';
 
 DROP TABLE deprecated_node;
 CREATE VIEW deprecated_node AS SELECT DISTINCT subject AS id FROM statements WHERE predicate='owl:deprecated' AND value='true';
@@ -1020,7 +1035,33 @@ DROP TABLE owl_axiom;
 CREATE VIEW owl_axiom AS SELECT * FROM owl_reified_axiom UNION SELECT NULL AS id, * FROM statements;
 
 DROP TABLE owl_axiom_annotation;
-CREATE VIEW owl_axiom_annotation AS SELECT axpv.stanza AS stanza, axs.object AS subject, axp.object AS predicate, axo.object AS object, axo.value AS value, axo.datatype AS datatype, axo.language AS language, axpv.subject AS id, axpv.predicate AS annotation_predicate, axpv.object AS annotation_iri, axpv.value AS annotation_value, axpv.language AS annotation_language, axpv.datatype AS annotation_datatype FROM statements AS axs, statements AS axp, statements AS axo, statements AS axpv WHERE axs.predicate = 'owl:annotatedSource' AND axp.predicate = 'owl:annotatedProperty' AND axo.predicate = 'owl:annotatedTarget' AND axs.subject = axpv.subject AND axp.subject = axpv.subject AND axo.subject = axpv.subject AND axpv.predicate NOT IN ('owl:annotatedSource', 'owl:annotatedProperty', 'owl:annotatedTarget', 'rdf:type');
+CREATE VIEW owl_axiom_annotation AS SELECT
+   axpv.stanza AS stanza,
+   axs.object AS subject,
+   axp.object AS predicate,
+   axo.object AS object,
+   axo.value AS value,
+   axo.datatype AS datatype,
+   axo.language AS language,
+   axpv.subject AS id,
+   axpv.subject AS annotation_subject,
+   axpv.predicate AS annotation_predicate,
+   axpv.object AS annotation_object,
+   axpv.value AS annotation_value,
+   axpv.language AS annotation_language,
+   axpv.datatype AS annotation_datatype
+  FROM
+   statements AS axs,
+   statements AS axp,
+   statements AS axo,
+   statements AS axpv
+  WHERE
+   axs.predicate = 'owl:annotatedSource' AND
+   axp.predicate = 'owl:annotatedProperty' AND
+   axo.predicate = 'owl:annotatedTarget' AND
+   axs.subject = axpv.subject AND
+   axp.subject = axpv.subject AND axo.subject = axpv.subject AND
+   axpv.predicate NOT IN ('owl:annotatedSource', 'owl:annotatedProperty', 'owl:annotatedTarget', 'rdf:type');
 
 DROP TABLE owl_some_values_from;
 CREATE VIEW owl_some_values_from AS SELECT onProperty.subject AS id,
